# Changelog

## v1.4.2

- Tested for different API structures 🏗️
- Code coverage at 100% again 👀
- Improvements by contributors 👍🏻

## V1.3.0

- Added `CORE_FOLDER` and `API_FOLDER` settings in order to organize code and separate concerns in our APIs:

```py
CORE_FOLDER = "my_core_folder_path/" # you can leave them empty
API_FOLDER = "my_api_folder_path/"   # or set them to be the same
```

- Core folder is for `models.py` `admin.py` and `migrations`
- API folder will contain `views.py` `serializers.py` and `urls.py`

## v1.0.1

- minor typo fix with URLs

## v1.0.0

- 100 % full test coverage 🚀
- Major changes and improvements 👍🏻
- Code quality and linting with pylint ✅
- CI/CD with travisCI 🏆

## v1.0-beta.1

- changes (Pre-release)

## v0.6-alpha

- few improvments
